clear all
clear matrix
set type double, perm
set varabbrev off, perm
cd /this_directory/


*log using rep_code_interim_risk.log, replace



*Figure 1
use mergers_main, replace
twoway (histogram mktrtn, bin(50) yaxis(2) xscale(range(-0.35(0.01)0.2))) ///
  (lpoly withdrawn mktrtn if majoritycash==1, yaxis(1) bw(0.06) lwidth(0.7) lcolor(edkblue) acolor(green%10) xscale(range(-0.35(0.01)0.2)) ylabel(0(0.1)1.0)) ///
  (lpoly withdrawn mktrtn if majoritystock==1, yaxis(1) bw(0.06) lwidth(0.7) lcolor(eltblue) acolor(green%10)  xscale(range(-0.35(0.01)0.2)) ylabel(0(0.1)1.0)) ///
  , legend(off) ytitle("", axis(2)) ylabel("", axis(2)) ///
    ylab(0 "0" .25 "25" .5 "50" .75 "75" 1 "100") ///
	xtitle(Market Return 20d Post-announcement) ///
    xlab(-0.3 "-30%" -0.2 "-20%" -0.1 "-10%" 0 "0%" 0.1 "+10%" 0.2 "+20%") ///
    ytitle("% Deals Withdrawn") yline(0, lcolor(black) lwidth(0.5) lpattern(dash)) ///
	text(0.31 -0.25 "Cash Deals", place(e)) ///
	text(0.1 -0.25 "Stock Deals", place(e)) ///
	graphregion(color(white)) bgcolor(white)
graph export Figure1.png, replace



*Figure 2
use daily_index_rtns, replace
gen logVW = log(1+vwretd)
keep date logVW
sort date
gen runtot = sum(logVW)
gen run_20 = runtot - runtot[_n-20]
drop if _n < 16300
gen down10 = run_20 < -0.10
gen c = 9 if down10
replace c = 5 if down10==0
format date %tdCY
twoway (area c date, yaxis(1) lw(8) lc(blue) color(eltblue) ysc(r(5 8.6))) ///
 (line runtot date, lwidth(0.2)), ///
 legend(off) xtitle("") ylabel("") ytitle(CRSP Value weighted U.S. Stock Market Index) ///
 graphregion(color(white)) bgcolor(white) ysize(4) xsize(8)
graph export Figure2.png, replace



*Figure 3
use mergers_main, replace
gen revision_bucket = ceil(revision / 10) / 10 - 0.05
drop revised
gen revised = (revision_bucket !=.)
drop if majoritycash==0 & majoritystock==0
bysort majoritycash majoritystock: gen ndeals = _N
di _N
drop if revision==0 | revision==.
collapse (sum) revised (lastnm) ndeals, by(majoritycash majoritystock revision_bucket)
replace revised = revised / ndeals
replace revision_bucket = 1 if revision_bucket > 1
twoway (bar revised revision_bucket if majoritystock==1, barw(0.1) lwidth(0.1) lpattern(dot) color(edkblue%40)) ///
       (bar revised revision_bucket if majoritycash==1, barw(0.1) fcolor(none) lcolor(black) lpattern(solid) lwidth(0.3)) ///
	   (pci -0.002 0 0.059 0, lcolor(black) lpattern(dash) lwidth(0.6)), ///
		xtitle(Revision From Initial Price) ytitle(Fraction of Revised Deals) ///
		legend(order(1 2) label(1 "Majority Stock") label(2 "Majority Cash") place(s)) ///
		xlabel(-1 "-100%" -0.5 "-50%" 0.0 "0%" 0.5 "+50%" 1 `""+100%" "or more""') ///
 	    graphregion(color(white)) bgcolor(white)
graph export Figure3.png, replace







*Table 1: summary stats.
use mergers_main, replace
di _N
tabstat value_deflated dealpremium_w ishostile PctOfCash PctOfStock completed, c(s) s(mean sd p10 p50 p90)
preserve
keep if majoritystock==1
di _N
tabstat value_deflated dealpremium_w ishostile PctOfCash PctOfStock completed, c(s) s(mean p50 sd)
restore
preserve
keep if majoritycash==1
di _N
tabstat value_deflated dealpremium_w ishostile PctOfCash PctOfStock completed, c(s) s(mean p50 sd)
restore
preserve
keep if pre_agreed==1
di _N
tabstat value_deflated dealpremium_w ishostile tenderoffer isbuyout PctOfCash PctOfStock completed AcquirorTotalAssets public_acq, c(s) s(mean p50 sd)
restore
preserve
keep if pre_agreed==0
di _N
tabstat value_deflated dealpremium_w ishostile tenderoffer isbuyout PctOfCash PctOfStock completed AcquirorTotalAssets public_acq, c(s) s(mean p50 sd)
restore



*Table 2
use mergers_main, replace
clogit completed mktrtn, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table2, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Model, Logit, Year FE, Yes) replace
clogit completed down, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table2, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Model, Logit, Year FE, Yes)
clogit completed down10, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table2, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Model, Logit, Year FE, Yes)
clogit completed down10 if majoritystock==1, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table2, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Model, Logit, Year FE, Yes)
clogit completed down10 if majoritycash==1, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table2, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Model, Logit, Year FE, Yes)




*Table 3
use mergers_main, replace
keep if majoritycash==1
clogit completed down5, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table3, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, Model, Logit, Year FE, Yes) replace
clogit completed down10, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table3, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, Model, Logit, Year FE, Yes)
clogit completed down15, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table3, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, Model, Logit, Year FE, Yes)
*
use mergers_main, clear
keep if majoritycash==1
keep dealID DateAnnounced deal_length completed TSIC4 year
expand 100
bysort dealID: gen date = DateAnnounced + _n
format date %td
merge m:1 date using daily_index_rtns, keep(match) nogen
bysort dealID (date): drop if _n > 40
gen temp = log(1+vwretd)
bysort dealID (date): gen mktrtn = temp if _n ==1
bysort dealID (date): replace mktrtn = mktrtn[_n-1] + temp if _n > 1
collapse (lastnm) mktrtn completed TSIC4 year, by(dealID)
gen down15 = (mktrtn < -0.15)
gen down10 = (mktrtn < -0.1)
gen down5 = (mktrtn < -0.05)
compress
clogit completed down5, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table3, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, Model, Logit, Year FE, Yes)
clogit completed down10, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table3, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, Model, Logit, Year FE, Yes)
clogit completed down15, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table3, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, Model, Logit, Year FE, Yes)
use mergers_main, clear
keep if majoritycash==1
keep dealID DateAnnounced deal_length completed TSIC4 year
expand 365
bysort dealID: gen date = DateAnnounced + _n
format date %td
merge m:1 date using daily_index_rtns, keep(match) nogen
bysort dealID (date): drop if _n > deal_length
gen temp = log(1+vwretd)
bysort dealID (date): gen mktrtn = temp if _n ==1
bysort dealID (date): replace mktrtn = mktrtn[_n-1] + temp if _n > 1
collapse (lastnm) mktrtn completed TSIC4 year, by(dealID)
gen down15 = (mktrtn < -0.15)
gen down10 = (mktrtn < -0.1)
gen down5 = (mktrtn < -0.05)
compress
clogit completed down5, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table3, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, Model, Logit, Year FE, Yes)
clogit completed down10, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table3, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, Model, Logit, Year FE, Yes)
clogit completed down15, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table3, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, Model, Logit, Year FE, Yes)






*Table 4
use mergers_main, replace
gen down10_stock = down10 * majoritystock
gen down10_cash = down10 * majoritycash
logit completed down10_stock down10_cash if pre_agreed==1, vce(cl TSIC4)
mfx
outreg2 using Table4A, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, Yes, Model, Logit) replace
logit completed down10_stock down10_cash if pre_agreed==0, vce(cl TSIC4)
mfx
outreg2 using Table4A, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Model, Logit)
keep if majoritycash==1
keep if pre_agreed==0
logit completed down10_cash if public_acq==1, vce(cl TSIC4)
mfx
outreg2 using Table4A, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Payment, Cash, Acquiror, Public, Model, Logit)
logit completed down10_cash if public_acq==0, vce(cl TSIC4)
mfx
outreg2 using Table4A, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Payment, Cash, Acquiror, Private, Model, Logit)
logit completed down10_cash if ishostile==1, vce(cl TSIC4)
mfx
outreg2 using Table4A, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Payment, Cash, Attitude, Hostile, Model, Logit)
logit completed down10_cash if ishostile==0, vce(cl TSIC4)
mfx
outreg2 using Table4A, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Payment, Cash, Attitude, Friendly, Model, Logit)
*
use mergers_main, replace
keep if majoritycash==1 & pre_agreed==0
bysort year: egen temp = median(logValue)
gen large_deal = (logValue > temp)
drop temp
logit completed down10 if large_deal==1, vce(cl TSIC4)
mfx
outreg2 using Table4B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Def Agreemt, No, Deal Size, Large, Payment, Cash, Model, Logit) replace
logit completed down10 if large_deal==0, vce(cl TSIC4)
mfx
outreg2 using Table4B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Deal Size, Small, Payment, Cash, Model, Logit)
logit completed down10 if isrelated==1, vce(cl TSIC4)
mfx
outreg2 using Table4B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Horizontal Mgr, Yes, Payment, Cash, Model, Logit)
logit completed down10 if isrelated==0, vce(cl TSIC4)
mfx
outreg2 using Table4B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Horizontal Mgr, No, Payment, Cash, Model, Logit)
logit completed down10 if isbuyout==1, vce(cl TSIC4)
mfx
outreg2 using Table4B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Buyout, Yes, Payment, Cash, Model, Logit)
logit completed down10 if isbuyout==0, vce(cl TSIC4)
mfx
outreg2 using Table4B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Buyout, No, Payment, Cash, Model, Logit)
logit completed down10 if tenderoffer==1, vce(cl TSIC4)
mfx
outreg2 using Table4B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Tender Offer, Yes, Payment, Cash, Model, Logit)
logit completed down10 if tenderoffer==0, vce(cl TSIC4)
mfx
outreg2 using Table4B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(DA in Place, No, Tender Offer, No, Payment, Cash, Model, Logit)







*Table 5
use mergers_main, replace
keep if pre_agreed==0 & majoritycash==1
clogit acq_withdrew down10, group(year) cl(TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table5A, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, DA in Place, No, Controls, No, Model, Logit, Year FE, Yes) replace
clogit tgt_rejected down10, group(year) cl(TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table5A, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, DA in Place, No, Controls, No, Model, Logit, Year FE, Yes)
clogit competing_bid down10, group(year) cl(TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table5A, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, DA in Place, No, Controls, No, Model, Logit, Year FE, Yes)
*
use mergers_main, replace
tab revised if majoritycash==1
tab revised if majoritystock==1
tab revised_down if majoritycash==1
tab revised_down if majoritystock==1
tab revised_up if majoritycash==1
tab revised_up if majoritystock==1
gen mktrtn_cash = mktrtn * majoritycash
gen mktrtn_stock = mktrtn * majoritystock
logit revised_down mktrtn_cash mktrtn_stock, cl(TSIC4) 
mfx
outreg2 using Table5B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Any, DA in Place, Any, Model, Logit, Year FE, Yes) replace
logit revised_down mktrtn_cash mktrtn_stock pre_agreed logValue loginitprem ishostile competing_bid, cl(TSIC4)
mfx
outreg2 using Table5B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Any, DA in Place, Any, Model, Logit, Year FE, Yes)
logit revised_up mktrtn_cash mktrtn_stock, cl(TSIC4)
mfx
outreg2 using Table5B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Any, DA in Place, Any, Model, Logit, Year FE, Yes)
logit revised_up mktrtn_cash mktrtn_stock pre_agreed logValue loginitprem ishostile competing_bid,  cl(TSIC4)
mfx
outreg2 using Table5B, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Any, DA in Place, Any, Model, Logit, Year FE, Yes)







*Table 6
use mergers_main, replace
replace PctOfCash = PctOfCash / 100
reghdfe PctOfCash down10, a(year) cl(TSIC4)
outreg2 using Table6A, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, Any, Model, OLS, Year FE, Yes) replace
reghdfe majoritycash down10, a(year) cl(TSIC4)
outreg2 using Table6A, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, Any, Model, OLS, Year FE, Yes)
reghdfe logpremium down10, a(year) cl(TSIC4)
outreg2 using Table6A, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, Any, Model, OLS, Year FE, Yes)
reghdfe logValue down10, a(year) cl(TSIC4)
outreg2 using Table6A, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, Any, Model, OLS, Year FE, Yes)
reghdfe logMB_acq down10, a(year) cl(TSIC4)
outreg2 using Table6A, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, Any, Model, OLS, Year FE, Yes)
reghdfe logMB_tgt down10, a(year) cl(TSIC4)
outreg2 using Table6A, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, Any, Model, OLS, Year FE, Yes)
*
preserve
keep if majoritycash==1
reghdfe logpremium down10, a(year) cl(TSIC4)
outreg2 using Table6B, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, Any, Model, OLS, Year FE, Yes) replace
reghdfe logValue down10, a(year) cl(TSIC4)
outreg2 using Table6B, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, Any, Model, OLS, Year FE, Yes)
reghdfe logMB_acq down10, a(year) cl(TSIC4)
outreg2 using Table6B, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, Any, Model, OLS, Year FE, Yes)
reghdfe logMB_tgt down10, a(year) cl(TSIC4)
outreg2 using Table6B, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, Any, Model, OLS, Year FE, Yes)
restore
*
preserve
drop if pre_agreed==1 
reghdfe logpremium down10, a(year) cl(TSIC4)
outreg2 using Table6C, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, No, Model, OLS, Year FE, Yes) replace
reghdfe logValue down10, a(year) cl(TSIC4)
outreg2 using Table6C, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, No, Model, OLS, Year FE, Yes)
reghdfe logMB_acq down10, a(year) cl(TSIC4)
outreg2 using Table6C, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, No, Model, OLS, Year FE, Yes)
reghdfe logMB_tgt down10, a(year) cl(TSIC4)
outreg2 using Table6C, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Any, DA in Place, No, Model, OLS, Year FE, Yes)
restore










*Table 7
use mergers_main, replace
keep if majoritycash==1 & pre_agreed==0
*
preserve
drop if logValue==.
egen temp = median(logValue)
gen largetgt = (logValue > temp)
gen interact_largetgt = largetgt * down10
gen interact_smalltgt = (largetgt==0) * down10
clogit completed interact_largetgt interact_smalltgt largetgt, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table7, mfx tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, No, Model, Logit, Year FE, Yes) replace
restore
*
preserve
drop if tgt_age==.
bysort year: egen temp = median(tgt_age)
gen hiage = (tgt_age >= temp)
gen interact_hiage = hiage * down10
gen interact_lowage = (hiage==0) * down10
clogit completed interact_lowage interact_hiage hiage, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table7, mfx tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, No, Model, Logit, Year FE, Yes)
restore
*
preserve
drop if tgt_vlt==.
bysort year: egen temp = median(tgt_vlt)
gen high_vol_target = tgt_vlt > temp
gen interact_highvol = high_vol_target * down10
gen interact_lowvol = (high_vol_target==0) * down10
clogit completed interact_highvol interact_lowvol high_vol_target, group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table7, mfx tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, No, Model, Logit, Year FE, Yes)
restore
*
preserve
drop if tgt_beta==.
egen temp = median(tgt_beta)
gen hibeta = (tgt_beta > temp)
gen interact_highbeta = hibeta * down10
gen interact_lowbeta = (hibeta==0) * down10
clogit completed interact_highbeta interact_lowbeta hibeta,group(year) vce(cl TSIC4) nonest
mfx, predict(pu0)
outreg2 using Table7, mfx tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, No, Model, Logit, Year FE, Yes)
restore






*Table 8
use mergers_main, replace
keep if majoritycash==1 & pre_agreed==0
preserve
logit completed down10 dCP, vce(cl TSIC4)
mfx
outreg2 using Table8, mfx tex(frag) stats(coef se) bdec(2) sdec(2) adds(Pseudo R2, `e(r2_p)') nocons label addtext(Payment, Cash, DA in Place, No, Model, Logit) replace
restore
*
preserve
drop if acq_che==.
gen constrained = acq_che < TgtSize
gen interact_constrained = down10 * constrained
gen interact_unconstrained = down10 * (constrained==0)
reg completed interact_constrained interact_unconstrained constrained, cl(TSIC4)
outreg2 using Table8, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, No, Model, OLS, FC Measure, AcqCash < TgtSize)
restore
*
preserve
drop if acq_tang==.
egen temp = median(acq_tang)
gen constrained = acq_tang < temp
gen interact_constrained = down10 * constrained
gen interact_unconstrained = down10 * (constrained==0)
reg completed interact_constrained interact_unconstrained constrained, cl(TSIC4)
outreg2 using Table8, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, No, Model, OLS, FC Measure, Acq Tangibility)
restore
*
preserve
drop if KZ==.
egen temp = median(KZ)
gen constrained = KZ > temp
gen interact_constrained = down10 * constrained
gen interact_unconstrained = down10 * (constrained==0)
reg completed interact_constrained interact_unconstrained constrained, cl(TSIC4)
outreg2 using Table8, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, No, Model, OLS, FC Measure, Acquiror KZ)
restore
*
preserve
drop if WW==.
egen temp = median(WW)
gen constrained = WW > temp
gen interact_constrained = down10 * constrained
gen interact_unconstrained = down10 * (constrained==0)
reg completed interact_constrained interact_unconstrained constrained, cl(TSIC4)
outreg2 using Table8, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, No, Model, OLS, FC Measure, Acquiror WW)
restore
*
preserve
drop if SA==.
egen temp = median(SA)
gen constrained = SA <= temp
gen interact_constrained = down10 * constrained
gen interact_unconstrained = down10 * (constrained==0)
reg completed interact_constrained interact_unconstrained constrained, cl(TSIC4)
outreg2 using Table8, tex(frag) stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, Cash, DA in Place, No, Model, OLS, FC Measure, Acquiror SA)
restore















*Table 9
use mergers_main, replace
drop if VIX==.
su VIX, d
logit majoritycash VIX CAPE, vce(cl TSIC4)
mfx
outreg2 using Table9, tex(frag) mfx stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, All, DA in Place, All, Model, Logit) replace
logit pre_agreed VIX CAPE, vce(cl TSIC4)
mfx
outreg2 using Table9, tex(frag) mfx stats(coef se) bdec(2) sdec(2) nocons label addtext(Payment, All, DA in Place, All, Model, Logit) 
gen vix_cash = VIX * majoritycash
gen vix_stock = VIX * majoritystock
gen cape_cash = CAPE * majoritycash
gen cape_stock = CAPE * majoritystock
*announced deals:
reghdfe logpremium vix_cash vix_stock cape_cash cape_stock majoritystock majoritycash, a(year) cl(TSIC4)
outreg2 using Table9, tex(frag) stats(coef se) bdec(2) sdec(2) adjr2 nocons label addtext(Payment, All, DA in Place, All, Model, OLS, Year FE, Yes)
reghdfe logValue vix_cash vix_stock cape_cash cape_stock majoritystock majoritycash, a(year) cl(TSIC4)
outreg2 using Table9, tex(frag) stats(coef se) bdec(2) sdec(2) adjr2 nocons label addtext(Payment, All, DA in Place, All, Model, OLS, Year FE, Yes)
reghdfe tgt_beta vix_cash vix_stock cape_cash cape_stock majoritystock majoritycash, a(year) cl(TSIC4)
outreg2 using Table9, tex(frag) stats(coef se) bdec(2) sdec(2) adjr2 nocons label addtext(Payment, All, DA in Place, All, Model, OLS, Year FE, Yes)
*completed deals:
preserve
keep if completed==1
reghdfe logpremium vix_cash vix_stock cape_cash cape_stock majoritystock majoritycash, a(year) cl(TSIC4)
outreg2 using Table9, tex(frag) stats(coef se) bdec(2) sdec(2) adjr2 nocons label addtext(Payment, All, DA in Place, All, Model, OLS, Year FE, Yes)
reghdfe logValue vix_cash vix_stock cape_cash cape_stock majoritystock majoritycash, a(year) cl(TSIC4)
outreg2 using Table9, tex(frag) stats(coef se) bdec(2) sdec(2) adjr2 nocons label  addtext(Payment, All, DA in Place, All, Model, OLS, Year FE, Yes)
reghdfe tgt_beta vix_cash vix_stock cape_cash cape_stock majoritystock majoritycash, a(year) cl(TSIC4)
outreg2 using Table9, tex(frag) stats(coef se) bdec(2) sdec(2) adjr2 nocons label addtext(Payment, All, DA in Place, All, Model, OLS, Year FE, Yes)
restore


*log close
